@@ -9,6 +9,7 @@
 #include "alloc.h"
 #include "util.h"
 #include "wiki.h"
+#include "template.h"
 
 #define ADD_ITEM_COUNT 10
 
@@ -18,6 +19,7 @@ typedef enum _NAVI {
     NAVI_PROJECT,
     NAVI_ITEM,
     NAVI_STYLE,
+    NAVI_EXPORT,
     NAVI_ADMIN_HELP
 } NaviType;
 
@@ -30,6 +32,8 @@ void items_action();
 void items_submit_action();
 void style_action();
 void style_submit_action();
+void export_action();
+void export_submit_action();
 void display_action();
 void new_item_action();
 void new_item_submit_action();
@@ -50,6 +54,8 @@ void register_actions()
     REG_ACTION(items_submit);
     REG_ACTION(style);
     REG_ACTION(style_submit);
+    REG_ACTION(export);
+    REG_ACTION(export_submit);
     REG_ACTION(new_item);
     REG_ACTION(new_item_submit);
     REG_ACTION(delete_item);
@@ -104,6 +110,7 @@ void output_header(Project* project, char* title, char* script_name, NaviType na
     o(      "\t\t<li><a %s href=\"%s/%s/project\">%s</a></li>\n", navi == NAVI_PROJECT ? "class=\"current\"" : "", cgiScriptName, g_project_code_4_url, _("sub project settings"));
     o(      "\t\t<li><a %s href=\"%s/%s/items\">%s</a></li>\n", navi == NAVI_ITEM ? "class=\"current\"" : "", cgiScriptName, g_project_code_4_url, _("columns settings"));
     o(      "\t\t<li><a %s href=\"%s/%s/style\">%s</a></li>\n", navi == NAVI_STYLE ? "class=\"current\"" : "", cgiScriptName, g_project_code_4_url, _("style settings"));
+    o(      "\t\t<li><a %s href=\"%s/%s/export\">%s</a></li>\n", navi == NAVI_EXPORT ? "class=\"current\"" : "", cgiScriptName, g_project_code_4_url, _("export settings"));
     o(      "\t\t<li><a %s href=\"%s/%s/admin_help\">%s</a></li>\n", navi == NAVI_ADMIN_HELP ? "class=\"current\"" : "", cgiScriptName, g_project_code_4_url, _("help"));
     o(      "\t<li><a href=\"%s/../index.%s/%s/\">%s", cgiScriptName, get_ext(cgiScriptName), g_project_code_4_url, _("to"));h(string_rawstr(project->name)); o("%s</a></li>\n", _("to(suffix)"));
     o(      "</ul>\n"
@@ -143,9 +150,8 @@ void top_action()
     Project* project_a = project_new();
     char message[DEFAULT_LENGTH];
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
 
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     project_a = db_get_project(db_a, project_a);
     output_header(project_a, _("menu"), NULL, NAVI_MENU);
 
@@ -162,6 +168,7 @@ void top_action()
     o("\t\t<dt><a href=\"%s/%s/project\">%s</a></dt><dd>%s</dd>\n", cgiScriptName, g_project_code_4_url, _("sub project settings"), _("this is basic sub projects settings."));
     o("\t\t<dt><a href=\"%s/%s/items\">%s</a></dt><dd>%s</dd>\n", cgiScriptName, g_project_code_4_url, _("columns settings"), _("this is columns settings of tickets."));
     o("\t\t<dt><a href=\"%s/%s/style\">%s</a></dt><dd>%s</dd>\n", cgiScriptName, g_project_code_4_url, _("style settings"), _("this is stylesheet settings."));
+    o("\t\t<dt><a href=\"%s/%s/export\">%s</a></dt><dd>%s</dd>\n", cgiScriptName, g_project_code_4_url, _("export settings"), _("this is export settings."));
     o("\t</dl>\n");
     o("</div>\n");
     o("<h3>%s</h3>\n", _("about mail notify features"));
@@ -183,9 +190,8 @@ void project_action()
 {
     Project* project_a = project_new();
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
 
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     project_a = db_get_project(db_a, project_a);
     output_header(project_a, _("sub project settings"), "management.js", NAVI_PROJECT);
 
@@ -252,9 +258,8 @@ void project_submit_action()
     Database* db_a;
     char name[DEFAULT_LENGTH];
     char upload_max_size_str[DEFAULT_LENGTH];
-    char buffer[DEFAULT_LENGTH];
 
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     db_begin(db_a);
     project_a = db_get_project(db_a, project_a);
     cgiFormStringNoNewlines("project.name", name, DEFAULT_LENGTH);
@@ -286,9 +291,8 @@ void items_action()
     List* element_types_a;
     Iterator* it;
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
 
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     project_a = db_get_project(db_a, project_a);
     output_header(project_a, _("columns settings"), "management.js", NAVI_ITEM);
 
@@ -547,8 +551,7 @@ void items_action()
 void items_submit_action()
 {
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     db_begin(db_a);
     update_elements();
     db_commit(db_a);
@@ -678,9 +681,8 @@ void new_item_action()
     Project* project_a = project_new();
     int i;
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
 
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     project_a = db_get_project(db_a, project_a);
     output_header(project_a, _("add new column"), "new_item.js", NAVI_OTHER);
 
@@ -832,9 +834,8 @@ void new_item_submit_action()
     char value[DEFAULT_LENGTH];
     int i, e_type_id;
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
 
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     db_begin(db_a);
 
     cgiFormStringNoNewlines("field.name", value, DEFAULT_LENGTH);
@@ -895,13 +896,12 @@ void delete_item_action()
     Project* project_a = project_new();
     ElementType* et_a = element_type_new();
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
 
     d("g_path_info: %s\n", g_path_info);
     e_type_id = g_path_info;
     iid = atoi(e_type_id);
     d("iid: %d\n", iid);
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     project_a = db_get_project(db_a, project_a);
     output_header(project_a, _("column delete"), "delete_item.js", NAVI_OTHER);
 
@@ -931,7 +931,6 @@ void delete_item_submit_action()
     char* e_type_id;
     int iid;
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
 
     /* postの時以外は処理しない。 */
     if (strcmp(cgiRequestMethod, "POST") != 0) {
@@ -940,7 +939,7 @@ void delete_item_submit_action()
     d("g_path_info: %s\n", g_path_info);
     e_type_id = g_path_info;
     iid = atoi(e_type_id);
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     db_begin(db_a);
 
     db_delete_element_type(db_a, iid);
@@ -952,9 +951,8 @@ void delete_item_submit_action()
 void style_action()
 {
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
     Project* project_a = project_new();
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     project_a = db_get_project(db_a, project_a);
     output_header(project_a, _("style settings"), "style.js", NAVI_STYLE);
     o(      "<h2>%s %s</h2>", string_rawstr(project_a->name), _("management tool"));
@@ -1014,7 +1012,6 @@ void style_submit_action()
 {
     SettingFile* sf_a = setting_file_new();
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
     string_set(sf_a->name, "user.css");
     string_set(sf_a->file_name, "");
     sf_a->content = xalloc(sizeof(char) * VALUE_LENGTH);
@@ -1022,7 +1019,7 @@ void style_submit_action()
     cgiFormString("edit_css", sf_a->content, VALUE_LENGTH);
     sf_a->size = strlen(sf_a->content);
     string_set(sf_a->mime_type, "text/css");
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     db_setting_file_save(db_a, sf_a);
     db_finish(db_a);
 
@@ -1033,8 +1030,7 @@ void admin_help_action()
 {
     Project* project_a = project_new();
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     project_a = db_get_project(db_a, project_a);
     output_header(project_a, "ヘルプ", NULL, NAVI_ADMIN_HELP);
     o(      "<h2>");h(string_rawstr(project_a->name));o("</h2>\n"
@@ -1045,4 +1041,46 @@ void admin_help_action()
     db_finish(db_a);
     output_footer();
 }
+void export_action()
+{
+    Project* project_a = project_new();
+    Database* db_a;
+
+    db_a = db_init(g_project_code);
+    project_a = db_get_project(db_a, project_a);
+    output_header(project_a, _("sub project settings"), "management.js", NAVI_PROJECT);
+
+    o("<h2>%s %s</h2>", string_rawstr(project_a->name), _("management tool"));
+    o("<div id=\"setting_form\">\n");
+    o("\t<form id=\"management_form\" action=\"%s/%s/export_submit\" method=\"post\">\n", cgiScriptName, g_project_code_4_url);
+    o("\t\t<h3>%s</h3>\n", _("export settings"));
+    o("\t\t<div class=\"description\">\n");
+    o("\t\t\t%s\n", _("this sub project columns settings are able to exported."));
+    o("\t\t\t%s\n", _("when you create sub project, you can select exported sub project types."));
+    o("\t\t</div>\n");
+    o("\t\t<table summary=\"project table\">\n");
+    o("\t\t\t<tr>\n");
+    o("\t\t\t\t<th>%s</th>\n", _("export sub project type name"));
+    o("\t\t\t\t<td><input type=\"text\" name=\"export_sub_project_type_name\" value=\"\" maxlength=\"1000\" /></td>\n");
+    o("\t\t\t</tr>\n");
+    o("\t\t</table>\n");
+    o("\t\t<input class=\"button\" type=\"submit\" value=\"%s\" />\n", _("register"));
+    o("\t</form>\n");
+    o("</div>\n");
+    project_free(project_a);
+    output_footer();
+    db_finish(db_a);
+}
+void export_submit_action()
+{
+    char project_type_name[DEFAULT_LENGTH];
+    String* locale = string_new();
+
+    cgiFormStringNoNewlines("export_sub_project_type_name", project_type_name, DEFAULT_LENGTH);
+    locale = db_top_get_locale(locale);
+    save_template(project_type_name, locale);
+    string_free(locale);
+
+    redirect("", _("updated."));
+}
 /* vim: set ts=4 sw=4 sts=4 expandtab fenc=utf-8: */
