@@ -13,6 +13,7 @@
 #include "hook.h"
 #include "csv.h"
 #include "simple_string.h"
+#include "template.h"
 
 void top_top_action();
 void top_update_project_submit_action();
@@ -91,7 +92,6 @@ int admin_top_main() {
 void top_top_action()
 {
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
     List* project_infos_a;
     Iterator* it;
     char** multi;
@@ -100,7 +100,7 @@ void top_top_action()
     d("top_top_action\n");
     list_alloc(project_infos_a, ProjectInfo, project_info_new, project_info_free);
 
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     project_infos_a = db_top_get_all_project_infos(db_a, project_infos_a);
     project_a = db_get_project(db_a, project_a);
     d("top_top_action\n");
@@ -170,7 +170,7 @@ void top_top_action()
         }
         project_a = project_new();
         sprintf(db_name, "db/%d.db", p->id);
-        db_project_a = db_init(db_name);
+        db_project_a = db_init(string_rawstr(p->code));
         project_a = db_get_project(db_project_a, project_a);
         o(      "\t\t\t<tr>\n");
         o(      "\t\t\t\t<td>"); h(string_rawstr(project_a->name)); o("</td>\n");
@@ -197,10 +197,32 @@ void top_top_action()
             "\t\t\t\t<tr>\n"
             "\t\t\t\t\t<th>%s</th>\n"
             "\t\t\t\t\t<th>%s</th>\n"
-            "\t\t\t\t</tr>\n", _("sub project id"), _("sort"));
+            "\t\t\t\t\t<th>%s</th>\n"
+            "\t\t\t\t</tr>\n", _("sub project id"), _("sort"), _("sub project type"));
     o(      "\t\t\t\t<tr>\n"
             "\t\t\t\t\t<td><input type=\"text\" name=\"project_new.code\" class=\"project_id\" value=\"\" /></td>\n"
-            "\t\t\t\t\t<td><input type=\"text\" name=\"project_new.sort\" class=\"number\" value=\"\" /></td>\n");
+            "\t\t\t\t\t<td><input type=\"text\" name=\"project_new.sort\" class=\"number\" value=\"\" /></td>\n"
+            "\t\t\t\t\t<td>\n"
+            "\t\t\t\t\t\t<select name=\"project_new.project_type\">\n"
+            "\t\t\t\t\t\t\t<option value=\"\">%s</option>\n", _("default bts"));
+    {
+        String* locale = string_new();
+        Iterator* it;
+        List* templates;
+        list_alloc(templates, Template, template_new, template_free);
+        locale = db_top_get_locale(locale);
+        templates = get_templates(templates, locale);
+        string_free(locale);
+        foreach (it, templates) {
+            Template* template = it->element;
+            o("\t\t\t\t\t\t<option name=\""); h(string_rawstr(template->name)); o("\">");
+            h(string_rawstr(template->name));
+            o("</option>\n");
+        }
+        list_free(templates);
+    }
+    o(      "\t\t\t\t\t\t</select>\n");
+    o(      "\t\t\t\t\t</td>\n");
     o(      "\t\t\t\t</tr>\n");
     o(      "\t\t\t</table>\n");
     o(      "\t\t\t<p>%s</p>\n", _("[sub project name description]"));
@@ -213,9 +235,8 @@ void top_top_action()
 void top_update_project_info_submit_action()
 {
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
 
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     {
         char name[DEFAULT_LENGTH];
         char home_description[DEFAULT_LENGTH];
@@ -267,9 +288,8 @@ static bool validate_project_code(char* name)
 void top_update_project_submit_action()
 {
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
 
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     {
         List* project_infos_a;
         Iterator* it;
@@ -322,13 +342,14 @@ void top_update_project_submit_action()
 void top_add_project_submit_action()
 {
     Database* db_a;
-    char buffer[DEFAULT_LENGTH];
 
-    db_a = db_init(db_top_get_project_db_name(g_project_code, buffer));
+    db_a = db_init(g_project_code);
     {
         char code[DEFAULT_LENGTH];
         char sort[DEFAULT_LENGTH];
+        char project_type[DEFAULT_LENGTH];
         ProjectInfo* pi_a = project_info_new();
+        int project_id;
 
         d("db->name: %s\n", db_a->name);
         cgiFormString("project_new.code", code, DEFAULT_LENGTH);
@@ -349,7 +370,14 @@ void top_add_project_submit_action()
         string_set(pi_a->code, code);
         cgiFormString("project_new.sort", sort, DEFAULT_LENGTH);
         pi_a->sort = atoi(sort);
-        db_top_register_project_info(db_a, pi_a);
+        cgiFormString("project_new.project_type", project_type, DEFAULT_LENGTH);
+        string_set(pi_a->project_type, project_type);
+        project_id = db_top_register_project_info(db_a, pi_a);
+        if (strlen(project_type)) {
+            /* プロジェクトタイプが指定されている場合は、DBを作成する。 */
+            d("create_db_from_template %d %s\n", project_id, project_type);
+            create_db_from_template(project_id, project_type);
+        }
         project_info_free(pi_a);
     }
     db_finish(db_a);
