@@ -6,7 +6,7 @@
 #include "dbutil.h"
 
 List* db_top_get_all_project_infos(Database*, List*);
-void db_top_register_project_info(Database*, ProjectInfo*);
+int db_top_register_project_info(Database*, ProjectInfo*);
 void db_top_update_project_infos(Database*, List*);
 void db_top_delete_project_info(Database*, ProjectInfo*);
 char* db_top_get_project_db_name(char*, char*);
@@ -15,6 +15,7 @@ void db_top_update_project(Database*, Project*);
 List* db_top_search(Database*, char*, List*);
 String* db_top_get_project_name(Database*, Ticket*, String*);
 String* db_top_get_title(Database*, Ticket*, String*);
+String* db_top_get_locale(String*);
 void db_top_set_locale();
 String* db_top_get_top_project_name(String*);
 #endif
